pub struct IdentityLink {
pub user_id: Uuid,
pub provider: IdentityProvider,
pub subject: String,
pub created_at: DateTime<Utc>,
}Expand description
Link between a user and an external identity provider (or local password).
Fields
user_id: Uuidprovider: IdentityProvidersubject: StringStable provider-side ID (e.g. GitHub user id; for password = email).
created_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for IdentityLink
impl Clone for IdentityLink
Sourcefn clone(&self) -> IdentityLink
fn clone(&self) -> IdentityLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for IdentityLink
impl ComposeSchema for IdentityLink
Sourceimpl Debug for IdentityLink
impl Debug for IdentityLink
Sourceimpl<'de> Deserialize<'de> for IdentityLink
impl<'de> Deserialize<'de> for IdentityLink
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for IdentityLink
Sourceimpl PartialEq for IdentityLink
impl PartialEq for IdentityLink
Sourcefn eq(&self, other: &IdentityLink) -> bool
fn eq(&self, other: &IdentityLink) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IdentityLink
impl Serialize for IdentityLink
impl StructuralPartialEq for IdentityLink